@@ -1,3 +1,4 @@
+// SPDX-License-Identifier: GPL-2.0
 #include "configuredivecomputer.h"
 #include <QTextStream>
 #include <QFile>
@@ -7,6 +8,7 @@
 #include <libxslt/transform.h>
 #include <QStringList>
 #include <QXmlStreamWriter>
+#include "core/version.h"
 
 ConfigureDiveComputer::ConfigureDiveComputer() : readThread(0),
 	writeThread(0),
@@ -629,16 +631,18 @@ QString ConfigureDiveComputer::dc_open(device_data_t *data)
 	if (fp) {
 		dc_context_set_loglevel(data->context, DC_LOGLEVEL_ALL);
 		dc_context_set_logfunc(data->context, logfunc, fp);
+		fprintf(data->libdc_logfile, "Subsurface: v%s, ", subsurface_git_version());
+		fprintf(data->libdc_logfile, "built with libdivecomputer v%s\n", dc_version(NULL));
 	}
 
-#if defined(SSRF_CUSTOM_SERIAL)
+#if defined(SSRF_CUSTOM_IO)
 	if (data->bluetooth_mode) {
-#if defined(BT_SUPPORT) && defined(SSRF_CUSTOM_SERIAL)
-		rc = dc_context_set_custom_serial(data->context, get_qt_serial_ops());
+#if defined(BT_SUPPORT) && defined(SSRF_CUSTOM_IO)
+		rc = dc_context_set_custom_io(data->context, get_qt_serial_ops(), data);
 #endif
 #ifdef SERIAL_FTDI
 	} else if (!strcmp(data->devname, "ftdi")) {
-		rc = dc_context_set_custom_serial(data->context, &serial_ftdi_ops);
+		rc = dc_context_set_custom_io(data->context, &serial_ftdi_ops, data);
 #endif
 	}
 
