@@ -421,7 +421,7 @@ extern struct picture *clone_picture(struct picture *src);
 extern bool dive_check_picture_time(struct dive *d, int shift_time, timestamp_t timestamp);
 extern void dive_create_picture(struct dive *d, const char *filename, int shift_time, bool match_all);
 extern void dive_add_picture(struct dive *d, struct picture *newpic);
-extern void dive_remove_picture(char *filename);
+extern bool dive_remove_picture(struct dive *d, char *filename);
 extern unsigned int dive_get_picture_count(struct dive *d);
 extern bool picture_check_valid(const char *filename, int shift_time);
 extern void picture_load_exif_data(struct picture *p);
@@ -723,7 +723,7 @@ extern int match_one_dc(struct divecomputer *a, struct divecomputer *b);
 extern void parse_xml_init(void);
 extern int parse_xml_buffer(const char *url, const char *buf, int size, struct dive_table *table, const char **params);
 extern void parse_xml_exit(void);
-extern void set_filename(const char *filename, bool force);
+extern void set_filename(const char *filename);
 
 extern int parse_dm4_buffer(sqlite3 *handle, const char *url, const char *buf, int size, struct dive_table *table);
 extern int parse_dm5_buffer(sqlite3 *handle, const char *url, const char *buf, int size, struct dive_table *table);
@@ -940,15 +940,13 @@ struct decostop {
 	int depth;
 	int time;
 };
-bool plan(struct deco_state *ds, struct diveplan *diveplan, struct dive *dive, int timestep, struct decostop *decostoptable, struct deco_state **cached_datap, bool is_planner, bool show_disclaimer);
-void calc_crushing_pressure(struct deco_state *ds, double pressure);
-void vpmb_start_gradient(struct deco_state *ds);
-void clear_vpmb_state();
-void printdecotable(struct decostop *table);
+extern bool plan(struct deco_state *ds, struct diveplan *diveplan, struct dive *dive, int timestep, struct decostop *decostoptable, struct deco_state **cached_datap, bool is_planner, bool show_disclaimer);
+extern void calc_crushing_pressure(struct deco_state *ds, double pressure);
+extern void vpmb_start_gradient(struct deco_state *ds);
+extern void clear_vpmb_state(struct deco_state *ds);
+extern void printdecotable(struct decostop *table);
 
-void delete_single_dive(int idx);
-
-struct event *get_next_event(struct event *event, const char *name);
+extern struct event *get_next_event(struct event *event, const char *name);
 
 static inline struct gasmix *get_gasmix(struct dive *dive, struct divecomputer *dc, int time, struct event **evp, struct gasmix *gasmix)
 {
