@@ -109,9 +109,7 @@ bool weightsystem_none(void *_data)
 
 bool no_weightsystems(weightsystem_t *ws)
 {
-	int i;
-
-	for (i = 0; i < MAX_WEIGHTSYSTEMS; i++)
+	for (int i = 0; i < MAX_WEIGHTSYSTEMS; i++)
 		if (!weightsystem_none(ws + i))
 			return false;
 	return true;
@@ -125,9 +123,7 @@ static bool one_weightsystem_equal(weightsystem_t *ws1, weightsystem_t *ws2)
 
 bool weightsystems_equal(weightsystem_t *ws1, weightsystem_t *ws2)
 {
-	int i;
-
-	for (i = 0; i < MAX_WEIGHTSYSTEMS; i++)
+	for (int i = 0; i < MAX_WEIGHTSYSTEMS; i++)
 		if (!one_weightsystem_equal(ws1 + i, ws2 + i))
 			return false;
 	return true;
@@ -227,10 +223,9 @@ void remove_weightsystem(struct dive *dive, int idx)
  * and if we are tracking gas consumption the pressures need to be reset to start = end = workingpressure */
 void reset_cylinders(struct dive *dive, bool track_gas)
 {
-	int i;
 	pressure_t decopo2 = {.mbar = prefs.decopo2};
 
-	for (i = 0; i < MAX_CYLINDERS; i++) {
+	for (int i = 0; i < MAX_CYLINDERS; i++) {
 		cylinder_t *cyl = &dive->cylinder[i];
 		if (cylinder_none(cyl))
 			continue;
@@ -242,3 +237,24 @@ void reset_cylinders(struct dive *dive, bool track_gas)
 		cyl->deco_gas_used.mliter = 0;
 	}
 }
+
+#ifdef DEBUG_CYL
+void dump_cylinders(struct dive *dive, bool verbose)
+{
+	printf("Cylinder list:\n");
+	for (int i = 0; i < MAX_CYLINDERS; i++) {
+		cylinder_t *cyl = &dive->cylinder[i];
+
+		printf("%02d: Type     %s, %3.1fl, %3.0fbar\n", i, cyl->type.description, cyl->type.size.mliter / 1000.0, cyl->type.workingpressure.mbar / 1000.0);
+		printf("    Gasmix   O2 %2.0f%% He %2.0f%%\n", cyl->gasmix.o2.permille / 10.0, cyl->gasmix.he.permille / 10.0);
+		printf("    Pressure Start %3.0fbar End %3.0fbar Sample start %3.0fbar Sample end %3.0fbar\n", cyl->start.mbar / 1000.0, cyl->end.mbar / 1000.0, cyl->sample_start.mbar / 1000.0, cyl->sample_end.mbar / 1000.0);
+		if (verbose) {
+			printf("    Depth    %3.0fm\n", cyl->depth.mm / 1000.0);
+			printf("    Added    %s\n", (cyl->manually_added ? "manually" : ""));
+			printf("    Gas used Bottom %5.0fl Deco %5.0fl\n", cyl->gas_used.mliter / 1000.0, cyl->deco_gas_used.mliter / 1000.0);
+			printf("    Use      %d\n", cyl->cylinder_use);
+			printf("    Bestmix  %s %s\n", (cyl->bestmix_o2 ? "O2" : "  "), (cyl->bestmix_he ? "He" : "  "));
+		}
+	}
+}
+#endif
