@@ -497,9 +497,8 @@ int parse_file(const char *filename)
 		return git_load_dives(git, branch);
 
 	if ((ret = readfile(filename, &mem)) < 0) {
-		/* we don't want to display an error if this was the default file or the cloud storage */
-		if ((prefs.default_filename && !strcmp(filename, prefs.default_filename)) ||
-		    isCloudUrl(filename))
+		/* we don't want to display an error if this was the default file  */
+		if (same_string(filename, prefs.default_filename))
 			return 0;
 
 		return report_error(translate("gettextFromC", "Failed to read '%s'"), filename);
@@ -928,6 +927,11 @@ int parse_dan_format(const char *filename, char **params, int pnr)
 				++iter;
 		}
 
+		if (!iter) {
+			fprintf(stderr, "DEBUG: Data corrupt");
+			return -1;
+		}
+
 		/* Setting date */
 		memcpy(tmpbuf, iter, 8);
 		tmpbuf[8] = 0;
@@ -951,9 +955,12 @@ int parse_dan_format(const char *filename, char **params, int pnr)
 		}
 		if (ptr)
 			ptr = strstr(ptr, NL);
-		if (ptr)
+		if (ptr) {
 			ptr += strlen(NL);
-
+		} else {
+			fprintf(stderr, "DEBUG: Data corrupt");
+			return -1;
+		}
 		end_ptr = ptr - (char *)mem.buffer;
 
 		/* Copy the current dive data to start of mem_csv buffer */
