@@ -252,6 +252,13 @@ static void copy_gps_location(struct gpsTracker &gps, struct dive *d)
 }
 
 #define SAME_GROUP 6 * 3600 /* six hours */
+#define SET_LOCATION(_dive, _gpsfix, _mark)	\
+{						\
+	copy_gps_location(_gpsfix, _dive);	\
+	changed = true;				\
+	last = _mark;				\
+}
+
 bool GpsLocation::applyLocations()
 {
 	int i;
@@ -283,9 +290,7 @@ bool GpsLocation::applyLocations()
 				if (time_during_dive_with_offset(d, gpsTable[j].when, 0)) {
 					if (verbose)
 						qDebug() << "gpsFix is during the dive, pick that one";
-					copy_gps_location(gpsTable[j], d);
-					changed = true;
-					last = j;
+					SET_LOCATION(d, gpsTable[j], j);
 					break;
 				} else {
 					/*
@@ -294,15 +299,6 @@ bool GpsLocation::applyLocations()
 					if (j + 1 < cnt && time_during_dive_with_offset(d, gpsTable[j+1].when, SAME_GROUP)) {
 						if (verbose)
 							qDebug() << "look at the next gps fix @" << get_dive_date_string(gpsTable[j+1].when);
-						/* first let's test if this one is during the dive */
-						if (time_during_dive_with_offset(d, gpsTable[j+1].when, 0)) {
-							if (verbose)
-								qDebug() << "which is during the dive, pick that one";
-							copy_gps_location(gpsTable[j+1], d);
-							changed = true;
-							last = j + 1;
-							break;
-						}
 						/* we know the gps fixes are sorted; if they are both before the dive, ignore the first,
 						 * if theay are both after the dive, take the first,
 						 * if the first is before and the second is after, take the closer one */
@@ -313,25 +309,19 @@ bool GpsLocation::applyLocations()
 						} else if (gpsTable[j].when > dive_endtime(d)) {
 							if (verbose)
 								qDebug() << "which is even later after the end of the dive, so pick the previous one";
-							copy_gps_location(gpsTable[j], d);
-							changed = true;
-							last = j;
+							SET_LOCATION(d, gpsTable[j], j);
 							break;
 						} else {
 							/* ok, gpsFix is before, nextgpsFix is after */
 							if (d->when - gpsTable[j].when <= gpsTable[j+1].when - dive_endtime(d)) {
 								if (verbose)
 									qDebug() << "pick the one before as it's closer to the start";
-								copy_gps_location(gpsTable[j], d);
-								changed = true;
-								last = j;
+								SET_LOCATION(d, gpsTable[j], j);
 								break;
 							} else {
 								if (verbose)
 									qDebug() << "pick the one after as it's closer to the start";
-								copy_gps_location(gpsTable[j+1], d);
-								changed = true;
-								last = j + 1;
+								SET_LOCATION(d, gpsTable[j + 1], j + 1);
 								break;
 							}
 						}
@@ -341,9 +331,7 @@ bool GpsLocation::applyLocations()
 					} else {
 						if (verbose)
 							qDebug() << "which seems to be the best one for this dive, so pick it";
-						copy_gps_location(gpsTable[j], d);
-						changed = true;
-						last = j;
+						SET_LOCATION(d, gpsTable[j], j);
 						break;
 					}
 				}
@@ -448,13 +436,12 @@ void GpsLocation::deleteFixFromStorage(gpsTracker &gt)
 
 void GpsLocation::deleteGpsFix(qint64 when)
 {
-	struct gpsTracker defaultTracker;
-	defaultTracker.when = 0;
-	struct gpsTracker deletedTracker = m_trackers.value(when, defaultTracker);
-	if (deletedTracker.when != when) {
-		qDebug() << "can't find tracker for timestamp" << when;
+	auto it = m_trackers.find(when);
+	if (it == m_trackers.end()) {
+		qWarning() << "GpsLocation::deleteGpsFix(): can't find tracker for timestamp " << when;
 		return;
 	}
+	struct gpsTracker deletedTracker = *it;
 	deleteFixFromStorage(deletedTracker);
 	m_deletedTrackers.append(deletedTracker);
 }
@@ -614,7 +601,7 @@ void GpsLocation::downloadFromServer()
 			qDebug() << downloadedFixes.count() << "GPS fixes downloaded";
 			for (int i = 0; i < downloadedFixes.count(); i++) {
 				QJsonObject fix = downloadedFixes[i].toObject();
-				QDate date = QDate::fromString(fix.value("date").toString(), "yyy-M-d");
+				QDate date = QDate::fromString(fix.value("date").toString(), "yyyy-M-d");
 				QTime time = QTime::fromString(fix.value("time").toString(), "hh:m:s");
 				QString name = fix.value("name").toString();
 				QString latitude = fix.value("latitude").toString();
