@@ -115,7 +115,7 @@ static int parse_gasmixes(device_data_t *devdata, struct dive *dive, dc_parser_t
 #endif
 	bool no_volume = true;
 
-	for (i = 0; i < ngases || i < ntanks; i++) {
+	for (i = 0; i < MAX_CYLINDERS && (i < ngases || i < ntanks); i++) {
 		if (i < ngases) {
 			dc_gasmix_t gasmix = { 0 };
 			int o2, he;
@@ -124,10 +124,7 @@ static int parse_gasmixes(device_data_t *devdata, struct dive *dive, dc_parser_t
 			if (rc != DC_STATUS_SUCCESS && rc != DC_STATUS_UNSUPPORTED)
 				return rc;
 
-			if (i >= MAX_CYLINDERS)
-				continue;
-
-			 o2 = lrint(gasmix.oxygen * 1000);
+			o2 = lrint(gasmix.oxygen * 1000);
 			he = lrint(gasmix.helium * 1000);
 
 			/* Ignore bogus data - libdivecomputer does some crazy stuff */
@@ -735,9 +732,12 @@ static dc_status_t libdc_header_parser(dc_parser_t *parser, device_data_t *devda
 		case DC_DIVEMODE_OC: /* Open circuit */
 			dive->dc.divemode = OC;
 			break;
-		case DC_DIVEMODE_CC:  /* Closed circuit */
+		case DC_DIVEMODE_CCR:  /* Closed circuit rebreather*/
 			dive->dc.divemode = CCR;
 			break;
+		case DC_DIVEMODE_SCR:  /* Semi-closed circuit rebreather */
+			dive->dc.divemode = PSCR;
+			break;
 		}
 #endif
 
@@ -804,6 +804,7 @@ static int dive_cb(const unsigned char *data, unsigned int size,
 	if (!devdata->force_download && find_dive(&dive->dc)) {
 		const char *date_string = get_dive_date_c_string(dive->when);
 		dev_info(devdata, translate("gettextFromC", "Already downloaded dive at %s"), date_string);
+		free((void *)date_string);
 		goto error_exit;
 	}
 
