@@ -394,6 +394,18 @@ static void parse_cylinder_keyvalue(void *_cylinder, const char *key, const char
 		cylinder->depth = get_depth(value);
 		return;
 	}
+	if ((*key == 'm') && strlen(value) == 0) {
+		/* found a bogus key/value pair in the cylinder, consisting
+		 * of a lonely "m" or m<single quote> without value. This
+		 * is caused by commit 46004c39e26 and fixed in 48d9c8eb6eb0 and
+		 * b984fb98c38e4. See referenced commits for more info.
+		 *
+		 * Just ignore this key/value pair. No processing is broken
+		 * due to this, as the git storage stores only metric SI type data.
+		 * In fact, the m unit is superfluous anyway.
+		 */
+		return;
+	}
 	report_error("Unknown cylinder key/value pair (%s/%s)", key, value);
 }
 
@@ -1566,16 +1578,18 @@ static int parse_picture_file(git_repository *repo, const git_tree_entry *entry,
 	/* remember the picture data so we can handle it when all dive data has been loaded
 	 * the name of the git file is PIC-<hash> */
 	git_blob *blob = git_tree_entry_blob(repo, entry);
-	const void *rawdata = git_blob_rawcontent(blob);
-	int len = git_blob_rawsize(blob);
-	struct picture_entry_list *new_pel = malloc(sizeof(struct picture_entry_list));
-	new_pel->next = pel;
-	pel = new_pel;
-	pel->data = malloc(len);
-	memcpy(pel->data, rawdata, len);
-	pel->len = len;
-	pel->hash = strdup(name + 4);
-	git_blob_free(blob);
+	if (blob) {
+		const void*rawdata = git_blob_rawcontent(blob);
+		int len = git_blob_rawsize(blob);
+		struct picture_entry_list *new_pel = malloc(sizeof(struct picture_entry_list));
+		new_pel->next = pel;
+		pel = new_pel;
+		pel->data = malloc(len);
+		memcpy(pel->data, rawdata, len);
+		pel->len = len;
+		pel->hash = strdup(name + 4);
+		git_blob_free(blob);
+	}
 	return 0;
 }
 
