@@ -1,3 +1,4 @@
+// SPDX-License-Identifier: GPL-2.0
 #include <QApplication>
 #include <QNetworkProxy>
 #include <QLibraryInfo>
@@ -39,32 +40,28 @@ void init_qt_late()
 	QString uiLang = uiLanguage(&loc);
 	QLocale::setDefault(loc);
 
-	// we don't have translations for English - if we don't check for this
-	// Qt will proceed to load the second language in preference order - not what we want
-	// on Linux this tends to be en-US, but on the Mac it's just en
-	if (!uiLang.startsWith("en") || uiLang.startsWith("en-GB")) {
-		qtTranslator = new QTranslator;
-		QString translationLocation;
+	qtTranslator = new QTranslator;
+	QString translationLocation;
 #if defined(Q_OS_ANDROID)
-		translationLocation = QLatin1Literal("assets:/translations");
+	translationLocation = QLatin1Literal("assets:/translations");
 #elif defined(Q_OS_IOS)
-		translationLocation = QLatin1Literal(":/translations/");
+	translationLocation = QLatin1Literal(":/translations/");
 #else
-		translationLocation = QLibraryInfo::location(QLibraryInfo::TranslationsPath);
+	translationLocation = QLibraryInfo::location(QLibraryInfo::TranslationsPath);
 #endif
-		if (qtTranslator->load(loc, "qt", "_", translationLocation)) {
-			application->installTranslator(qtTranslator);
-		} else {
+	if (qtTranslator->load(loc, "qt", "_", translationLocation)) {
+		application->installTranslator(qtTranslator);
+	} else {
+		if (verbose && uiLang != "en_US" && uiLang != "en-US")
 			qDebug() << "can't find Qt localization for locale" << uiLang << "searching in" << translationLocation;
-		}
-		ssrfTranslator = new QTranslator;
-		if (ssrfTranslator->load(loc, "subsurface", "_") ||
-		    ssrfTranslator->load(loc, "subsurface", "_", translationLocation) ||
-		    ssrfTranslator->load(loc, "subsurface", "_", getSubsurfaceDataPath("translations")) ||
-		    ssrfTranslator->load(loc, "subsurface", "_", getSubsurfaceDataPath("../translations"))) {
-			application->installTranslator(ssrfTranslator);
-		} else {
-			qDebug() << "can't find Subsurface localization for locale" << uiLang;
-		}
+	}
+	ssrfTranslator = new QTranslator;
+	if (ssrfTranslator->load(loc, "subsurface", "_") ||
+	    ssrfTranslator->load(loc, "subsurface", "_", translationLocation) ||
+	    ssrfTranslator->load(loc, "subsurface", "_", getSubsurfaceDataPath("translations")) ||
+	    ssrfTranslator->load(loc, "subsurface", "_", getSubsurfaceDataPath("../translations"))) {
+		application->installTranslator(ssrfTranslator);
+	} else {
+		qDebug() << "can't find Subsurface localization for locale" << uiLang;
 	}
 }
