@@ -560,15 +560,10 @@ QLocale getLocale()
 	return loc;
 }
 
-void set_filename(const char *filename, bool force)
+void set_filename(const char *filename)
 {
-	if (!force && existing_filename)
-		return;
 	free((void *)existing_filename);
-	if (filename)
-		existing_filename = strdup(filename);
-	else
-		existing_filename = NULL;
+	existing_filename = copy_string(filename);
 }
 
 const QString get_dc_nickname(const char *model, uint32_t deviceid)
@@ -1113,7 +1108,7 @@ void write_hashes()
 		stream << thumbnailCache;
 		hashfile.commit();
 	} else {
-		qDebug() << "cannot open" << hashfile.fileName();
+		qWarning() << "Cannot open hashfile for writing: " << hashfile.fileName();
 	}
 }
 
@@ -1454,16 +1449,6 @@ extern "C" char *cloud_url()
 	return strdup(filename.toUtf8().data());
 }
 
-extern "C" bool isCloudUrl(const char *filename)
-{
-	QString email = QString(prefs.cloud_storage_email);
-	email.replace(QRegularExpression("[^a-zA-Z0-9@._+-]"), "");
-	if (!email.isEmpty() &&
-	    QString(QString(prefs.cloud_git_url) + "/%1[%1]").arg(email) == filename)
-		return true;
-	return false;
-}
-
 extern "C" bool getProxyString(char **buffer)
 {
 	if (prefs.proxy_type == QNetworkProxy::HttpProxy) {
@@ -1713,14 +1698,17 @@ char *intdup(int index)
 
 QHash<int, double> factor_cache;
 
-QMutex factorCacheLock;
+QReadWriteLock factorCacheLock;
 extern "C" double cache_value(int tissue, int timestep, enum inertgas inertgas)
 {
+	double value;
 	int key = (timestep << 5) + (tissue << 1);
 	if (inertgas == HE)
 		++key;
-	QMutexLocker locker(&factorCacheLock);
-	return factor_cache.value(key);
+	factorCacheLock.lockForRead();
+	value = factor_cache.value(key);
+	factorCacheLock.unlock();
+	return value;
 }
 
 extern "C" void cache_insert(int tissue, int timestep, enum inertgas inertgas, double value)
@@ -1728,8 +1716,9 @@ extern "C" void cache_insert(int tissue, int timestep, enum inertgas inertgas, d
 	int key = (timestep << 5) + (tissue << 1);
 	if (inertgas == HE)
 		++key;
-	QMutexLocker locker(&factorCacheLock);
+	factorCacheLock.lockForWrite();
 	factor_cache.insert(key, value);
+	factorCacheLock.unlock();
 }
 
 extern "C" void print_qt_versions()
