@@ -158,7 +158,7 @@ static void save_cylinder_info(struct membuffer *b, struct dive *dive)
 		if (cylinder->cylinder_use != OC_GAS)
 			put_format(b, " use=%s", cylinderuse_text[cylinder->cylinder_use]);
 		if (cylinder->depth.mm != 0)
-			put_milli(b, " depth='", cylinder->depth.mm, " m'");
+			put_milli(b, " depth=", cylinder->depth.mm, "m");
 		put_string(b, "\n");
 	}
 }
@@ -1099,7 +1099,9 @@ static void create_commit_message(struct membuffer *msg, bool create_empty)
 		} while ((dc = dc->next) != NULL);
 		put_format(msg, "\n");
 	}
-	put_format(msg, "Created by %s\n", subsurface_user_agent());
+	const char *user_agent = subsurface_user_agent();
+	put_format(msg, "Created by %s\n", user_agent);
+	free((void *)user_agent);
 }
 
 static int create_new_commit(git_repository *repo, const char *remote, const char *branch, git_oid *tree_id, bool create_empty)
@@ -1149,22 +1151,30 @@ static int create_new_commit(git_repository *repo, const char *remote, const cha
 	/* If the parent commit has the same tree ID, do not create a new commit */
 	if (parent && git_oid_equal(tree_id, git_commit_tree_id((const git_commit *) parent))) {
 		/* If the parent already came from the ref, the commit is already there */
-		if (ref)
+		if (ref) {
+			git_signature_free(author);
 			return 0;
+		}
 		/* Else we do want to create the new branch, but with the old commit */
 		commit = (git_commit *) parent;
 	} else {
 		struct membuffer commit_msg = { 0 };
 
 		create_commit_message(&commit_msg, create_empty);
-		if (git_commit_create_v(&commit_id, repo, NULL, author, author, NULL, mb_cstring(&commit_msg), tree, parent != NULL, parent))
+		if (git_commit_create_v(&commit_id, repo, NULL, author, author, NULL, mb_cstring(&commit_msg), tree, parent != NULL, parent)) {
+			git_signature_free(author);
 			return report_error("Git commit create failed (%s)", strerror(errno));
+		}
 		free_buffer(&commit_msg);
 
-		if (git_commit_lookup(&commit, repo, &commit_id))
+		if (git_commit_lookup(&commit, repo, &commit_id)) {
+			git_signature_free(author);
 			return report_error("Could not look up newly created commit");
+		}
 	}
 
+	git_signature_free(author);
+
 	if (!ref) {
 		if (git_branch_create(&ref, repo, branch, commit, 0))
 			return report_error("Failed to create branch '%s'", branch);
@@ -1196,8 +1206,6 @@ static int create_new_commit(git_repository *repo, const char *remote, const cha
 	if (! create_empty)
 		set_git_id(&commit_id);
 
-	git_signature_free(author);
-
 	return 0;
 }
 
