@@ -29,6 +29,11 @@ QString DiveComputerSettings::dc_device() const
 	return prefs.dive_computer.device;
 }
 
+QString DiveComputerSettings::dc_device_name() const
+{
+	return prefs.dive_computer.device_name;
+}
+
 int DiveComputerSettings::downloadMode() const
 {
 	return prefs.dive_computer.download_mode;
@@ -42,7 +47,7 @@ void DiveComputerSettings::setVendor(const QString& vendor)
 	QSettings s;
 	s.beginGroup(group);
 	s.setValue("dive_computer_vendor", vendor);
-	free(prefs.dive_computer.vendor);
+	free((void *)prefs.dive_computer.vendor);
 	prefs.dive_computer.vendor = copy_string(qPrintable(vendor));
 }
 
@@ -54,7 +59,7 @@ void DiveComputerSettings::setProduct(const QString& product)
 	QSettings s;
 	s.beginGroup(group);
 	s.setValue("dive_computer_product", product);
-	free(prefs.dive_computer.product);
+	free((void *)prefs.dive_computer.product);
 	prefs.dive_computer.product = copy_string(qPrintable(product));
 }
 
@@ -66,10 +71,22 @@ void DiveComputerSettings::setDevice(const QString& device)
 	QSettings s;
 	s.beginGroup(group);
 	s.setValue("dive_computer_device", device);
-	free(prefs.dive_computer.device);
+	free((void *)prefs.dive_computer.device);
 	prefs.dive_computer.device = copy_string(qPrintable(device));
 }
 
+void DiveComputerSettings::setDeviceName(const QString& device_name)
+{
+	if (device_name == prefs.dive_computer.device_name)
+		return;
+
+	QSettings s;
+	s.beginGroup(group);
+	s.setValue("dive_computer_device_name", device_name);
+	free((void *)prefs.dive_computer.device_name);
+	prefs.dive_computer.device_name = copy_string(qPrintable(device_name));
+}
+
 void DiveComputerSettings::setDownloadMode(int mode)
 {
 	if (mode == prefs.dive_computer.download_mode)
@@ -127,7 +144,7 @@ void UpdateManagerSettings::setLastVersionUsed(const QString& value)
 	QSettings s;
 	s.beginGroup(group);
 	s.setValue("LastVersionUsed", value);
-	free (prefs.update_manager.last_version_used);
+	free((void *)prefs.update_manager.last_version_used);
 	prefs.update_manager.last_version_used = copy_string(qPrintable(value));
 	emit lastVersionUsedChanged(value);
 }
@@ -140,7 +157,7 @@ void UpdateManagerSettings::setNextCheck(const QDate& date)
 	QSettings s;
 	s.beginGroup(group);
 	s.setValue("NextCheck", date);
-	free (prefs.update_manager.next_check);
+	free((void *)prefs.update_manager.next_check);
 	prefs.update_manager.next_check = copy_string(qPrintable(date.toString("dd/MM/yyyy")));
 	emit nextCheckChanged(date);
 }
@@ -152,17 +169,17 @@ PartialPressureGasSettings::PartialPressureGasSettings(QObject* parent):
 
 }
 
-short PartialPressureGasSettings::showPo2() const
+bool PartialPressureGasSettings::showPo2() const
 {
 	return prefs.pp_graphs.po2;
 }
 
-short PartialPressureGasSettings::showPn2() const
+bool PartialPressureGasSettings::showPn2() const
 {
 	return prefs.pp_graphs.pn2;
 }
 
-short PartialPressureGasSettings::showPhe() const
+bool PartialPressureGasSettings::showPhe() const
 {
 	return prefs.pp_graphs.phe;
 }
@@ -188,7 +205,7 @@ double PartialPressureGasSettings::pheThreshold() const
 	return prefs.pp_graphs.phe_threshold;
 }
 
-void PartialPressureGasSettings::setShowPo2(short value)
+void PartialPressureGasSettings::setShowPo2(bool value)
 {
 	if (value == prefs.pp_graphs.po2)
 		return;
@@ -200,7 +217,7 @@ void PartialPressureGasSettings::setShowPo2(short value)
 	emit showPo2Changed(value);
 }
 
-void PartialPressureGasSettings::setShowPn2(short value)
+void PartialPressureGasSettings::setShowPn2(bool value)
 {
 	if (value == prefs.pp_graphs.pn2)
 		return;
@@ -212,7 +229,7 @@ void PartialPressureGasSettings::setShowPn2(short value)
 	emit showPn2Changed(value);
 }
 
-void PartialPressureGasSettings::setShowPhe(short value)
+void PartialPressureGasSettings::setShowPhe(bool value)
 {
 	if (value == prefs.pp_graphs.phe)
 		return;
@@ -296,7 +313,7 @@ void TechnicalDetailsSettings::setDecoMode(deco_mode d)
 	emit decoModeChanged(d);
 }
 
-double TechnicalDetailsSettings:: modp02() const
+double TechnicalDetailsSettings:: modpO2() const
 {
 	return prefs.modpO2;
 }
@@ -416,7 +433,7 @@ bool TechnicalDetailsSettings::showPicturesInProfile() const
 	return prefs.show_pictures_in_profile;
 }
 
-void TechnicalDetailsSettings::setModp02(double value)
+void TechnicalDetailsSettings::setModpO2(double value)
 {
 	if (value == prefs.modpO2)
 		return;
@@ -731,6 +748,7 @@ void FacebookSettings::setAccessToken (const QString& value)
 	s.beginGroup(subgroup);
 	s.setValue("ConnectToken", value);
 #endif
+	free((void *)prefs.facebook.access_token);
 	prefs.facebook.access_token = copy_string(qPrintable(value));
 	emit accessTokenChanged(value);
 }
@@ -745,6 +763,7 @@ void FacebookSettings::setUserId(const QString& value)
 	s.beginGroup(subgroup);
 	s.setValue("UserId", value);
 #endif
+	free((void *)prefs.facebook.user_id);
 	prefs.facebook.user_id = copy_string(qPrintable(value));
 	emit userIdChanged(value);
 }
@@ -759,6 +778,7 @@ void FacebookSettings::setAlbumId(const QString& value)
 	s.beginGroup(subgroup);
 	s.setValue("AlbumId", value);
 #endif
+	free((void *)prefs.facebook.album_id);
 	prefs.facebook.album_id = copy_string(qPrintable(value));
 	emit albumIdChanged(value);
 }
@@ -871,8 +891,8 @@ void ProxySettings::setHost(const QString& value)
 	QSettings s;
 	s.beginGroup(group);
 	s.setValue("proxy_host", value);
-	free(prefs.proxy_host);
-	prefs.proxy_host = copy_string(qPrintable(value));;
+	free((void *)prefs.proxy_host);
+	prefs.proxy_host = copy_string(qPrintable(value));
 	emit hostChanged(value);
 }
 
@@ -905,7 +925,7 @@ void ProxySettings::setUser(const QString& value)
 	QSettings s;
 	s.beginGroup(group);
 	s.setValue("proxy_user", value);
-	free(prefs.proxy_user);
+	free((void *)prefs.proxy_user);
 	prefs.proxy_user = copy_string(qPrintable(value));
 	emit userChanged(value);
 }
@@ -917,7 +937,7 @@ void ProxySettings::setPass(const QString& value)
 	QSettings s;
 	s.beginGroup(group);
 	s.setValue("proxy_pass", value);
-	free(prefs.proxy_pass);
+	free((void *)prefs.proxy_pass);
 	prefs.proxy_pass = copy_string(qPrintable(value));
 	emit passChanged(value);
 }
@@ -990,7 +1010,7 @@ void CloudStorageSettings::setPassword(const QString& value)
 	QSettings s;
 	s.beginGroup(group);
 	s.setValue("password", value);
-	free(prefs.cloud_storage_password);
+	free((void *)prefs.cloud_storage_password);
 	prefs.cloud_storage_password = copy_string(qPrintable(value));
 	emit passwordChanged(value);
 }
@@ -1000,7 +1020,7 @@ void CloudStorageSettings::setNewPassword(const QString& value)
 	if (value == prefs.cloud_storage_newpassword)
 		return;
 	/*TODO: This looks like wrong, but 'new password' is not saved on disk, why it's on prefs? */
-	free(prefs.cloud_storage_newpassword);
+	free((void *)prefs.cloud_storage_newpassword);
 	prefs.cloud_storage_newpassword = copy_string(qPrintable(value));
 	emit newPasswordChanged(value);
 }
@@ -1012,7 +1032,7 @@ void CloudStorageSettings::setEmail(const QString& value)
 	QSettings s;
 	s.beginGroup(group);
 	s.setValue("email", value);
-	free(prefs.cloud_storage_email);
+	free((void *)prefs.cloud_storage_email);
 	prefs.cloud_storage_email = copy_string(qPrintable(value));
 	emit emailChanged(value);
 }
@@ -1024,7 +1044,7 @@ void CloudStorageSettings::setUserId(const QString& value)
 	//WARNING: UserId is stored outside of any group, but it belongs to Cloud Storage.
 	QSettings s;
 	s.setValue("subsurface_webservice_uid", value);
-	free(prefs.userid);
+	free((void *)prefs.userid);
 	prefs.userid = copy_string(qPrintable(value));
 	emit userIdChanged(value);
 }
@@ -1034,7 +1054,7 @@ void CloudStorageSettings::setEmailEncoded(const QString& value)
 	if (value == prefs.cloud_storage_email_encoded)
 		return;
 	/*TODO: This looks like wrong, but 'email encoded' is not saved on disk, why it's on prefs? */
-	free(prefs.cloud_storage_email_encoded);
+	free((void *)prefs.cloud_storage_email_encoded);
 	prefs.cloud_storage_email_encoded = copy_string(qPrintable(value));
 	emit emailEncodedChanged(value);
 }
@@ -1072,7 +1092,7 @@ void CloudStorageSettings::setBackgroundSync(bool value)
 	emit backgroundSyncChanged(value);
 }
 
-void CloudStorageSettings::setSaveUserIdLocal(short int value)
+void CloudStorageSettings::setSaveUserIdLocal(bool value)
 {
 	//TODO: this is not saved on disk?
 	if (value == prefs.save_userid_local)
@@ -1081,7 +1101,7 @@ void CloudStorageSettings::setSaveUserIdLocal(short int value)
 	emit saveUserIdLocalChanged(value);
 }
 
-short int CloudStorageSettings::saveUserIdLocal() const
+bool CloudStorageSettings::saveUserIdLocal() const
 {
 	return prefs.save_userid_local;
 }
@@ -1093,8 +1113,8 @@ void CloudStorageSettings::setBaseUrl(const QString& value)
 
 	// dont free data segment.
 	if (prefs.cloud_base_url != default_prefs.cloud_base_url) {
-		free((void*)prefs.cloud_base_url);
-		free((void*)prefs.cloud_git_url);
+		free((void *)prefs.cloud_base_url);
+		free((void *)prefs.cloud_git_url);
 	}
 	QSettings s;
 	s.beginGroup(group);
@@ -1583,7 +1603,7 @@ int UnitsSettings::durationUnits() const
 	return prefs.units.duration_units;
 }
 
-int UnitsSettings::showUnitsTable() const
+bool UnitsSettings::showUnitsTable() const
 {
 	return prefs.units.show_units_table;
 }
@@ -1608,7 +1628,7 @@ void UnitsSettings::setLength(int value)
 	QSettings s;
 	s.beginGroup(group);
 	s.setValue("length", value);
-	prefs.units.length = (units::LENGHT) value;
+	prefs.units.length = (units::LENGTH) value;
 	emit lengthChanged(value);
 }
 
@@ -1678,7 +1698,7 @@ void UnitsSettings::setDurationUnits(int value)
 	emit durationUnitChanged(value);
 }
 
-void UnitsSettings::setShowUnitsTable(int value)
+void UnitsSettings::setShowUnitsTable(bool value)
 {
 	if (value == prefs.units.show_units_table)
 		return;
@@ -1775,6 +1795,7 @@ void GeneralSettingsObjectWrapper::setDefaultFilename(const QString& value)
 	QSettings s;
 	s.beginGroup(group);
 	s.setValue("default_filename", value);
+	free((void *)prefs.default_filename);
 	prefs.default_filename = copy_string(qPrintable(value));
 	emit defaultFilenameChanged(value);
 }
@@ -1787,6 +1808,7 @@ void GeneralSettingsObjectWrapper::setDefaultCylinder(const QString& value)
 	QSettings s;
 	s.beginGroup(group);
 	s.setValue("default_cylinder", value);
+	free((void *)prefs.default_cylinder);
 	prefs.default_cylinder = copy_string(qPrintable(value));
 	emit defaultCylinderChanged(value);
 }
@@ -1873,7 +1895,7 @@ double DisplaySettingsObjectWrapper::fontSize() const
 	return prefs.font_size;
 }
 
-short DisplaySettingsObjectWrapper::displayInvalidDives() const
+bool DisplaySettingsObjectWrapper::displayInvalidDives() const
 {
 	return prefs.display_invalid_dives;
 }
@@ -1915,7 +1937,7 @@ void DisplaySettingsObjectWrapper::setFontSize(double value)
 	emit fontSizeChanged(value);
 }
 
-void DisplaySettingsObjectWrapper::setDisplayInvalidDives(short value)
+void DisplaySettingsObjectWrapper::setDisplayInvalidDives(bool value)
 {
 	if (value == prefs.display_invalid_dives)
 		return;
@@ -1979,7 +2001,7 @@ void LanguageSettingsObjectWrapper::setUseSystemLanguage(bool value)
 	QSettings s;
 	s.beginGroup(group);
 	s.setValue("UseSystemLanguage", value);
-	prefs.locale.use_system_language = copy_string(qPrintable(value));
+	prefs.locale.use_system_language = value;
 	emit useSystemLanguageChanged(value);
 }
 
@@ -1990,6 +2012,7 @@ void  LanguageSettingsObjectWrapper::setLangLocale(const QString &value)
 	QSettings s;
 	s.beginGroup(group);
 	s.setValue("UiLangLocale", value);
+	free((void *)prefs.locale.lang_locale);
 	prefs.locale.lang_locale = copy_string(qPrintable(value));
 	emit langLocaleChanged(value);
 }
@@ -2001,6 +2024,7 @@ void  LanguageSettingsObjectWrapper::setLanguage(const QString& value)
 	QSettings s;
 	s.beginGroup(group);
 	s.setValue("UiLanguage", value);
+	free((void *)prefs.locale.language);
 	prefs.locale.language = copy_string(qPrintable(value));
 	emit languageChanged(value);
 }
@@ -2012,7 +2036,8 @@ void  LanguageSettingsObjectWrapper::setTimeFormat(const QString& value)
 	QSettings s;
 	s.beginGroup(group);
 	s.setValue("time_format", value);
-	prefs.time_format = copy_string(qPrintable(value));;
+	free((void *)prefs.time_format);
+	prefs.time_format = copy_string(qPrintable(value));
 	emit timeFormatChanged(value);
 }
 
@@ -2024,7 +2049,8 @@ void  LanguageSettingsObjectWrapper::setDateFormat(const QString& value)
 	QSettings s;
 	s.beginGroup(group);
 	s.setValue("date_format", value);
-	prefs.date_format = copy_string(qPrintable(value));;
+	free((void *)prefs.date_format);
+	prefs.date_format = copy_string(qPrintable(value));
 	emit dateFormatChanged(value);
 }
 
@@ -2036,7 +2062,8 @@ void  LanguageSettingsObjectWrapper::setDateFormatShort(const QString& value)
 	QSettings s;
 	s.beginGroup(group);
 	s.setValue("date_format_short", value);
-	prefs.date_format_short = copy_string(qPrintable(value));;
+	free((void *)prefs.date_format_short);
+	prefs.date_format_short = copy_string(qPrintable(value));
 	emit dateFormatShortChanged(value);
 }
 
@@ -2166,7 +2193,7 @@ void SettingsObjectWrapper::load()
 	}
 	GET_UNIT("vertical_speed_time", vertical_speed_time, units::MINUTES, units::SECONDS);
 	GET_UNIT3("duration_units", duration_units, units::MIXED, units::ALWAYS_HOURS, units::DURATION);
-	GET_UNIT_INT("show_units_table", show_units_table);
+	GET_UNIT_BOOL("show_units_table", show_units_table);
 	GET_BOOL("coordinates", coordinates_traditional);
 	s.endGroup();
 	s.beginGroup("TecDetails");
@@ -2245,7 +2272,7 @@ void SettingsObjectWrapper::load()
 	}
 	defaultFont.setPointSizeF(prefs.font_size);
 	qApp->setFont(defaultFont);
-	GET_INT("displayinvalid", display_invalid_dives);
+	GET_BOOL("displayinvalid", display_invalid_dives);
 	s.endGroup();
 
 	s.beginGroup("Animations");
@@ -2333,6 +2360,7 @@ void SettingsObjectWrapper::load()
 	GET_TXT("dive_computer_vendor",dive_computer.vendor);
 	GET_TXT("dive_computer_product", dive_computer.product);
 	GET_TXT("dive_computer_device", dive_computer.device);
+	GET_TXT("dive_computer_device_name", dive_computer.device_name);
 	GET_INT("dive_computer_download_mode", dive_computer.download_mode);
 	s.endGroup();
 
