@@ -90,8 +90,8 @@ struct preferences default_prefs = {
 	},
 	.planner_deco_mode = BUEHLMANN,
 	.vpmb_conservatism = 3,
-	.distance_threshold = 1000,
-	.time_threshold = 600,
+	.distance_threshold = 100,
+	.time_threshold = 300,
 #if defined(SUBSURFACE_MOBILE)
 	.cloud_timeout = 10,
 #else
@@ -204,7 +204,7 @@ static void print_help()
 	printf("\n --version             Prints current version");
 	printf("\n --survey              Offer to submit a user survey");
 	printf("\n --user=<test>         Choose configuration space for user <test>");
-	printf("\n --cloud-timeout=<nr>  Set timeout for cloud connection (0 < timeout < 60)");
+	printf("\n --cloud-timeout=<nr>  Set timeout for cloud connection (0 < timeout < 60)\n\n");
 }
 
 void parse_argument(const char *arg)
@@ -290,7 +290,6 @@ void setup_system_prefs(void)
 {
 	const char *env;
 
-	subsurface_OS_pref_setup();
 	default_prefs.divelist_font = strdup(system_divelist_default_font);
 	default_prefs.font_size = system_divelist_default_font_size;
 
