@@ -1,3 +1,4 @@
+// SPDX-License-Identifier: GPL-2.0
 #ifndef TAXONOMY_H
 #define TAXONOMY_H
 
@@ -16,13 +17,20 @@ enum taxonomy_category {
 	TC_NR_CATEGORIES
 };
 
+enum taxonomy_origin {
+	GEOCODED,
+	GEOPARSED,
+	GEOMANUAL,
+	GEOCOPIED
+};
+
 extern char *taxonomy_category_names[TC_NR_CATEGORIES];
 extern char *taxonomy_api_names[TC_NR_CATEGORIES];
 
 struct taxonomy {
 	int category;		/* the category for this tag: ocean, country, admin_l1, admin_l2, localname, etc */
 	const char *value;	/* the value returned, parsed, or manually entered for that category */
-	enum { GEOCODED, PARSED, MANUAL, COPIED } origin;
+	enum taxonomy_origin origin;
 };
 
 /* the data block contains 3 taxonomy structures - unused ones have a tag value of NONE */
@@ -34,6 +42,8 @@ struct taxonomy_data {
 struct taxonomy *alloc_taxonomy();
 void free_taxonomy(struct taxonomy_data *t);
 int taxonomy_index_for_category(struct taxonomy_data *t, enum taxonomy_category cat);
+const char *taxonomy_get_country(struct taxonomy_data *t);
+void taxonomy_set_country(struct taxonomy_data *t, const char *country, enum taxonomy_origin origin);
 
 #ifdef __cplusplus
 }
