@@ -1,3 +1,4 @@
+// SPDX-License-Identifier: GPL-2.0
 #ifdef __clang__
 // Clang has a bug on zero-initialization of C structs.
 #pragma clang diagnostic ignored "-Wmissing-field-initializers"
@@ -18,7 +19,7 @@
 char *getGoogleApi()
 {
 	/* google maps api auth*/
-	return "https://maps.googleapis.com/maps/api/js?key=AIzaSyDzo9PWsqYDDSddVswg_13rpD9oH_dLuoQ";
+	return "https://maps.googleapis.com/maps/api/js?";
 }
 
 void writeMarkers(struct membuffer *b, const bool selected_only)
