@@ -904,7 +904,13 @@ void ConfigureDiveComputerDialog::configError(QString err)
 
 void ConfigureDiveComputerDialog::getDeviceData()
 {
-	device_data.devname = strdup(ui.device->currentText().toUtf8().data());
+#ifdef BT_SUPPORT
+	QString device = ui.bluetoothMode && btDeviceSelectionDialog ?
+		btDeviceSelectionDialog->getSelectedDeviceAddress() : ui.device->currentText();
+#else
+	QString device = ui.device->currentText();
+#endif
+	device_data.devname = strdup(device.toUtf8().data());
 	device_data.vendor = strdup(selected_vendor.toUtf8().data());
 	device_data.product = strdup(selected_product.toUtf8().data());
 
@@ -913,6 +919,10 @@ void ConfigureDiveComputerDialog::getDeviceData()
 
 	auto dc = SettingsObjectWrapper::instance()->dive_computer_settings;
 	dc->setDevice(device_data.devname);
+#ifdef BT_SUPPORT
+	if (ui.bluetoothMode && btDeviceSelectionDialog)
+		dc->setDeviceName(btDeviceSelectionDialog->getSelectedDeviceName());
+#endif
 }
 
 void ConfigureDiveComputerDialog::on_cancel_clicked()
@@ -1488,7 +1498,7 @@ void ConfigureDiveComputerDialog::selectRemoteBluetoothDevice()
 void ConfigureDiveComputerDialog::bluetoothSelectionDialogIsFinished(int result)
 {
 	if (result == QDialog::Accepted) {
-		ui.device->setCurrentText(btDeviceSelectionDialog->getSelectedDeviceAddress());
+		ui.device->setCurrentText(btDeviceSelectionDialog->getSelectedDeviceText());
 		device_data.bluetooth_mode = true;
 
 		ui.progressBar->setFormat("Connecting to device...");
