@@ -1017,8 +1017,8 @@ QString DiveListView::lastUsedImageDir()
 
 	settings.beginGroup("FileDialog");
 	if (settings.contains("LastImageDir"))
-		if (QDir::setCurrent(settings.value("LastImageDir").toString()))
-			lastImageDir = settings.value("LastIamgeDir").toString();
+		if (QDir(settings.value("LastImageDir").toString()).exists())
+			lastImageDir = settings.value("LastImageDir").toString();
 	return lastImageDir;
 }
 
