@@ -14,9 +14,11 @@ public:
 protected:
 	void mouseDoubleClickEvent(QMouseEvent *event) Q_DECL_OVERRIDE;
 	void mousePressEvent(QMouseEvent *event) Q_DECL_OVERRIDE;
+	void wheelEvent(QWheelEvent *event) Q_DECL_OVERRIDE;
 
 signals:
 	void photoDoubleClicked(const QString filePath);
+	void zoomLevelChanged(int delta);
 };
 
 class DivePictureThumbnailThread : public QThread {
