@@ -606,15 +606,12 @@ void MainWindow::on_actionCloudstorageopen_triggered()
 
 	closeCurrentFile();
 
-	int error;
-
 	showProgressBar();
 	QByteArray fileNamePtr = QFile::encodeName(filename);
 	if (!parse_file(fileNamePtr.data())) {
-		set_filename(fileNamePtr.data(), true);
-		setTitle(MWTF_FILENAME);
+		set_filename(fileNamePtr.data());
+		setTitle();
 	}
-	getNotificationWidget()->hideNotification();
 	process_dives(false, false);
 	hideProgressBar();
 	refreshDisplay();
@@ -642,8 +639,8 @@ void MainWindow::on_actionCloudstoragesave_triggered()
 	if (error)
 		return;
 
-	set_filename(filename.toUtf8().data(), true);
-	setTitle(MWTF_FILENAME);
+	set_filename(filename.toUtf8().data());
+	setTitle();
 	mark_divelist_changed(false);
 }
 
@@ -694,7 +691,7 @@ void MainWindow::cleanUpEmpty()
 	dive_list()->reload(DiveTripModel::TREE);
 	MapWidget::instance()->reload();
 	if (!existing_filename)
-		setTitle(MWTF_DEFAULT);
+		setTitle();
 	disableShortcuts();
 }
 
@@ -1655,8 +1652,8 @@ int MainWindow::file_save_as(void)
 	if (save_dives(filename.toUtf8().data()))
 		return -1;
 
-	set_filename(filename.toUtf8().data(), true);
-	setTitle(MWTF_FILENAME);
+	set_filename(filename.toUtf8().data());
+	setTitle();
 	mark_divelist_changed(false);
 	addRecentFile(filename, true);
 	return 0;
@@ -1727,21 +1724,15 @@ void MainWindow::setAutomaticTitle()
 	setTitle();
 }
 
-void MainWindow::setTitle(enum MainWindowTitleFormat format)
+void MainWindow::setTitle()
 {
-	switch (format) {
-	case MWTF_DEFAULT:
+	if (!existing_filename || !existing_filename[0]) {
 		setWindowTitle("Subsurface");
-		break;
-	case MWTF_FILENAME:
-		if (!existing_filename) {
-			setTitle(MWTF_DEFAULT);
-			return;
-		}
-		QString unsaved = (unsaved_changes() ? " *" : "");
-		setWindowTitle("Subsurface: " + displayedFilename(existing_filename) + unsaved);
-		break;
+		return;
 	}
+
+	QString unsaved = (unsaved_changes() ? " *" : "");
+	setWindowTitle("Subsurface: " + displayedFilename(existing_filename) + unsaved);
 }
 
 void MainWindow::importFiles(const QStringList fileNames)
@@ -1801,9 +1792,9 @@ void MainWindow::loadFiles(const QStringList fileNames)
 	for (int i = 0; i < fileNames.size(); ++i) {
 		fileNamePtr = QFile::encodeName(fileNames.at(i));
 		if (!parse_file(fileNamePtr.data())) {
-			set_filename(fileNamePtr.data(), true);
+			set_filename(fileNamePtr.data());
 			addRecentFile(fileNamePtr, false);
-			setTitle(MWTF_FILENAME);
+			setTitle();
 		}
 	}
 	hideProgressBar();
