@@ -7,7 +7,7 @@
 
 #include "qt-models/models.h"
 
-PreferencesGraph::PreferencesGraph() : AbstractPreferencesWidget(tr("Profile"), QIcon(":graph"), 5)
+PreferencesGraph::PreferencesGraph() : AbstractPreferencesWidget(tr("Profile"), QIcon(":graph-icon"), 5)
 {
 	ui = new Ui::PreferencesGraph();
 	ui->setupUi(this);
@@ -62,7 +62,7 @@ void PreferencesGraph::syncSettings()
 	pp_gas->setPn2Threshold(ui->pn2Threshold->value());
 
 	auto tech = SettingsObjectWrapper::instance()->techDetails;
-	tech->setModp02(ui->maxpo2->value());
+	tech->setModpO2(ui->maxpo2->value());
 	tech->setRedceiling(ui->red_ceiling->isChecked());
 	tech->setBuehlmann(ui->buehlmann->isChecked());
 	tech->setGflow(ui->gflow->value());
