@@ -126,7 +126,7 @@ void UserSurvey::requestReceived()
 	}
 
 	msgbox.setWindowTitle(msgTitle);
-	msgbox.setWindowIcon(QIcon(":/subsurface-icon"));
+	msgbox.setWindowIcon(QIcon(":subsurface-icon"));
 	msgbox.setText(msgText);
 	msgbox.setTextFormat(Qt::RichText);
 	msgbox.exec();
