@@ -240,7 +240,7 @@ void QMLManager::openLocalThenRemote(QString url)
 		prefs.git_local_only = false;
 		appendTextToLog(QStringLiteral("taking things online to be able to switch to cloud account"));
 	}
-	set_filename(fileNamePrt.data(), true);
+	set_filename(fileNamePrt.data());
 	if (prefs.git_local_only) {
 		appendTextToLog(QStringLiteral("have cloud credentials, but user asked not to connect to network"));
 		alreadySaving = false;
@@ -318,7 +318,7 @@ void QMLManager::finishSetup()
 			// we got an error loading the local file
 			appendTextToLog(QString("got error %2 when parsing file %1").arg(existing_filename, get_error_string()));
 			setNotificationText(tr("Error parsing local storage, giving up"));
-			set_filename(NULL, true);
+			set_filename(NULL);
 		} else {
 			// successfully opened the local file, now add thigs to the dive list
 			consumeFinishedLoad(0);
@@ -596,7 +596,7 @@ void QMLManager::loadDivesWithValidCredentials()
 		report_error("filename is now %s", fileNamePrt.data());
 		QString errorString(get_error_string());
 		appendTextToLog(errorString);
-		set_filename(fileNamePrt.data(), true);
+		set_filename(fileNamePrt.data());
 	} else {
 		report_error("failed to open file %s", fileNamePrt.data());
 		QString errorString(get_error_string());
@@ -657,7 +657,7 @@ void QMLManager::revertToNoCloudIfNeeded()
 		setCloudUserName("");
 		setCloudPassword("");
 		setCredentialStatus(CS_NOCLOUD);
-		set_filename(NOCLOUD_LOCALSTORAGE, true);
+		set_filename(NOCLOUD_LOCALSTORAGE);
 		setStartPageText(RED_FONT + tr("Failed to connect to cloud server, reverting to no cloud status") + END_FONT);
 	}
 	alreadySaving = false;
@@ -714,7 +714,7 @@ bool QMLManager::checkDate(DiveObjectHelper *myDive, struct dive * d, QString da
 		// what a pain - Qt will not parse dates if the day of the week is incorrect
 		// so if the user changed the date but didn't update the day of the week (most likely behavior, actually),
 		// we need to make sure we don't try to parse that
-		QString format(QString(prefs.date_format) + QChar(' ') + prefs.time_format);
+		QString format(QString(prefs.date_format_short) + QChar(' ') + prefs.time_format);
 		if (format.contains(QLatin1String("ddd")) || format.contains(QLatin1String("dddd"))) {
 			QString dateFormatToDrop = format.contains(QLatin1String("ddd")) ? QStringLiteral("ddd") : QStringLiteral("dddd");
 			QDateTime ts;
@@ -814,12 +814,15 @@ parsed:
 bool QMLManager::checkLocation(DiveObjectHelper *myDive, struct dive *d, QString location, QString gps)
 {
 	bool diveChanged = false;
-
-	struct dive_site *ds = get_dive_site_by_uuid(d->dive_site_uuid);
+	uint32_t uuid = 0;
+	struct dive_site *ds = get_dive_site_for_dive(d);
 	if (myDive->location() != location) {
 		diveChanged = true;
-		ds = get_dive_site_by_uuid(create_dive_site(qPrintable(location), d->when));
-		d->dive_site_uuid = ds->uuid;
+		if (!ds)
+			uuid = get_dive_site_uuid_by_name(qPrintable(location), NULL);
+		if (!uuid && !location.isEmpty())
+			uuid = create_dive_site(qPrintable(location), d->when);
+		d->dive_site_uuid = uuid;
 	}
 	// now make sure that the GPS coordinates match - if the user changed the name but not
 	// the GPS coordinates, this still does the right thing as the now new dive site will
@@ -918,6 +921,12 @@ void QMLManager::commitChanges(QString diveId, QString date, QString location, Q
 			       QString startpressure, QString endpressure, QString gasmix, QString cylinder, int rating, int visibility)
 {
 	struct dive *d = get_dive_by_uniq_id(diveId.toInt());
+
+	if (!d) {
+		appendTextToLog("cannot commit changes: no dive");
+		return;
+	}
+
 	DiveObjectHelper *myDive = new DiveObjectHelper(d);
 
 	// notes comes back as rich text - let's convert this into plain text
@@ -925,10 +934,6 @@ void QMLManager::commitChanges(QString diveId, QString date, QString location, Q
 	doc.setHtml(notes);
 	notes = doc.toPlainText();
 
-	if (!d) {
-		appendTextToLog("cannot commit changes: no dive");
-		return;
-	}
 	bool diveChanged = false;
 	bool needResort = false;
 
@@ -982,7 +987,7 @@ void QMLManager::commitChanges(QString diveId, QString date, QString location, Q
 		diveChanged = true;
 		unsigned long i;
 		int size = 0, wp = 0;
-		for (i = 0; i < sizeof(tank_info) && tank_info[i].name != NULL; i++) {
+		for (i = 0; i < MAX_TANK_INFO && tank_info[i].name != NULL; i++) {
 			if (tank_info[i].name == cylinder ) {
 				if (tank_info[i].ml > 0){
 					size = tank_info[i].ml;
@@ -1008,11 +1013,9 @@ void QMLManager::commitChanges(QString diveId, QString date, QString location, Q
 		if (buddy.contains(",")){
 			buddy = buddy.replace(QRegExp("\\s*,\\s*"), ", ");
 		}
-		if (!buddy.contains("Multiple Buddies")) {
-			diveChanged = true;
-			free(d->buddy);
-			d->buddy = strdup(qPrintable(buddy));
-		}
+		diveChanged = true;
+		free(d->buddy);
+		d->buddy = strdup(qPrintable(buddy));
 	}
 	if (myDive->divemaster() != diveMaster) {
 		diveChanged = true;
@@ -1101,10 +1104,10 @@ void QMLManager::openNoCloudRepo()
 	if (git == dummy_git_repository) {
 		if (git_create_local_repo(filename))
 			appendTextToLog(get_error_string());
-		set_filename(filename, true);
-		GeneralSettingsObjectWrapper s(this);
-		s.setDefaultFilename(filename);
-		s.setDefaultFileBehavior(LOCAL_DEFAULT_FILE);
+		set_filename(filename);
+		auto s = SettingsObjectWrapper::instance()->general_settings;
+		s->setDefaultFilename(filename);
+		s->setDefaultFileBehavior(LOCAL_DEFAULT_FILE);
 	}
 
 	openLocalThenRemote(filename);
@@ -1118,10 +1121,10 @@ void QMLManager::saveChangesLocal()
 				char *filename = NOCLOUD_LOCALSTORAGE;
 				if (git_create_local_repo(filename))
 					appendTextToLog(get_error_string());
-				set_filename(filename, true);
-				GeneralSettingsObjectWrapper s(this);
-				s.setDefaultFilename(filename);
-				s.setDefaultFileBehavior(LOCAL_DEFAULT_FILE);
+				set_filename(filename);
+				auto s = SettingsObjectWrapper::instance()->general_settings;
+				s->setDefaultFilename(filename);
+				s->setDefaultFileBehavior(LOCAL_DEFAULT_FILE);
 			}
 		} else if (!loadFromCloud()) {
 			// this seems silly, but you need a common ancestor in the repository in
@@ -1140,7 +1143,7 @@ void QMLManager::saveChangesLocal()
 			QString errorString(get_error_string());
 			appendTextToLog(errorString);
 			setNotificationText(errorString);
-			set_filename(NULL, true);
+			set_filename(NULL);
 			prefs.git_local_only = glo;
 			alreadySaving = false;
 			return;
@@ -1258,6 +1261,7 @@ QString QMLManager::addDive()
 void QMLManager::addDiveAborted(int id)
 {
 	DiveListModel::instance()->removeDiveById(id);
+	delete_single_dive(get_idx_by_uniq_id(id));
 }
 
 QString QMLManager::getCurrentPosition()
@@ -1483,7 +1487,7 @@ void QMLManager::setCredentialStatus(const cloud_status_qml value)
 		setOldStatus(m_credentialStatus);
 		if (value == CS_NOCLOUD) {
 			appendTextToLog("Switching to no cloud mode");
-			set_filename(NOCLOUD_LOCALSTORAGE, true);
+			set_filename(NOCLOUD_LOCALSTORAGE);
 			clearCredentials();
 		}
 		m_credentialStatus = value;
@@ -1520,7 +1524,7 @@ QString QMLManager::getDate(const QString& diveId)
 	struct dive *d = get_dive_by_uniq_id(dive_id);
 	QString datestring;
 	if (d)
-		datestring = get_dive_date_string(d->when);
+		datestring = get_short_dive_date_string(d->when);
 	return datestring;
 }
 
@@ -1786,6 +1790,7 @@ void QMLManager::setStatusbarColor(QColor color)
 #else
 void QMLManager::setStatusbarColor(QColor color)
 {
+	Q_UNUSED(color)
 	// noop
 }
 
