@@ -9,9 +9,7 @@
 #include <QElapsedTimer>
 #include <QColor>
 
-#if defined(BT_SUPPORT)
 #include "core/btdiscovery.h"
-#endif
 #include "core/gpslocation.h"
 #include "core/downloadfromdcthread.h"
 #include "qt-models/divelistmodel.h"
@@ -138,9 +136,7 @@ public:
 	bool showPin() const;
 	void setShowPin(bool enable);
 	Q_INVOKABLE void setStatusbarColor(QColor color);
-#if defined(BT_SUPPORT)
 	void btHostModeChange(QBluetoothLocalDevice::HostMode state);
-#endif
 
 #if defined(Q_OS_ANDROID)
 	void writeToAppLogFile(QString logText);
@@ -184,6 +180,7 @@ public slots:
 	QString getNumber(const QString& diveId);
 	QString getDate(const QString& diveId);
 	QString getCurrentPosition();
+	QString getGpsFromSiteName(const QString& siteName);
 	QString getVersion() const;
 	void deleteGpsFix(quint64 when);
 	void revertToNoCloudIfNeeded();
@@ -195,6 +192,8 @@ public slots:
 	void appendTextToLog(const QString &newText);
 	void quit();
 	void hasLocationSourceChanged();
+	void btRescan();
+
 
 private:
 	QString m_cloudUserName;
