@@ -13,6 +13,8 @@
 # Qt/5.9/android_armv7/lib/cmake/Qt5Core/Qt5CoreConfigExtras.cmake
 # (this script tries to do this automatically)
 
+set -x # make debugging Travis easier
+
 exec 1> >(tee ./build.log) 2>&1
 
 USE_X=$(case $- in *x*) echo "-x" ;; esac)
@@ -22,7 +24,7 @@ USE_X=$(case $- in *x*) echo "-x" ;; esac)
 QT_VERSION=5.9
 LATEST_QT=5.9.1
 NDK_VERSION=r14b
-SDK_VERSION=3859397
+SDK_VERSION=3859397  # if you change this version, you'll likely have to change the android-sdk-license key fallback below
 
 ANDROID_NDK=android-ndk-${NDK_VERSION}
 ANDROID_SDK=android-sdk-linux
@@ -60,20 +62,7 @@ if [ "$MISSING" ] ; then
 	exit 1
 fi
 
-# download the Qt installer including Android bits and unpack / install
-QT_DOWNLOAD_URL=https://download.qt.io/archive/qt/${QT_VERSION}/${LATEST_QT}/${QT_BINARIES}
-if [ ! -d Qt ] ; then
-	if [ ! -f ${QT_BINARIES} ] ; then
-		wget -q ${QT_DOWNLOAD_URL}
-	fi
-	chmod +x ./${QT_BINARIES}
-	./${QT_BINARIES} --platform minimal --script "$SUBSURFACE_SOURCE"/qt-installer-noninteractive.qs --no-force-installations
-fi
-
-# patch the cmake / Qt5.7.1 incompatibility mentioned above
-sed -i 's/set_property(TARGET Qt5::Core PROPERTY INTERFACE_COMPILE_FEATURES cxx_decltype)/# set_property(TARGET Qt5::Core PROPERTY INTERFACE_COMPILE_FEATURES cxx_decltype)/' Qt/${LATEST_QT}/android_armv7/lib/cmake/Qt5Core/Qt5CoreConfigExtras.cmake
-
-# next we need to get the Android SDK and NDK
+# first we need to get the Android SDK and NDK
 if [ ! -d $ANDROID_NDK ] ; then
 	if [ ! -f $NDK_BINARIES ] ; then
 		wget -q https://dl.google.com/android/repository/$NDK_BINARIES
@@ -88,12 +77,27 @@ if [ ! -d $ANDROID_SDK ] ; then
 	mkdir $ANDROID_SDK
 	pushd $ANDROID_SDK
 	unzip -q ../$SDK_TOOLS
-	yes | tools/bin/sdkmanager --licenses
+	yes | tools/bin/sdkmanager --licenses > /dev/null 2>&1 || echo "d56f5187479451eabf01fb78af6dfcb131a6481e" > licenses/android-sdk-license
+	cat licenses/android-sdk-license
+	echo ""
 	# FIXME: Read these from build.sh varables, or install them there.
 	tools/bin/sdkmanager tools platform-tools 'platforms;android-27' 'build-tools;25.0.3'
 	popd
 fi
 
+# download the Qt installer including Android bits and unpack / install
+QT_DOWNLOAD_URL=https://download.qt.io/archive/qt/${QT_VERSION}/${LATEST_QT}/${QT_BINARIES}
+if [ ! -d Qt ] ; then
+	if [ ! -f ${QT_BINARIES} ] ; then
+		wget -q ${QT_DOWNLOAD_URL}
+	fi
+	chmod +x ./${QT_BINARIES}
+	./${QT_BINARIES} --platform minimal --script "$SUBSURFACE_SOURCE"/qt-installer-noninteractive.qs --no-force-installations
+fi
+
+# patch the cmake / Qt5.7.1 incompatibility mentioned above
+sed -i 's/set_property(TARGET Qt5::Core PROPERTY INTERFACE_COMPILE_FEATURES cxx_decltype)/# set_property(TARGET Qt5::Core PROPERTY INTERFACE_COMPILE_FEATURES cxx_decltype)/' Qt/${LATEST_QT}/android_armv7/lib/cmake/Qt5Core/Qt5CoreConfigExtras.cmake
+
 if [ ! -d subsurface/libdivecomputer/src ] ; then
 	pushd subsurface
 	git submodule init
