@@ -8,22 +8,27 @@ set -e
 TOP=$(pwd)
 SUBSURFACE_SOURCE=${TOP}/../../../subsurface
 IOS_QT=${TOP}/Qt
-QT_VERSION=$(cd ${IOS_QT}; ls -d 5.*)
+QT_VERSION=$(cd ${IOS_QT}; ls -d [1-9]* | awk -F. '{ printf("%02d.%02d.%02d\n", $1,$2,$3); }' | sort -n | tail -1 | sed -e 's/\.0/\./g;s/^0//')
+
+if [ -z $QT_VERSION ] ; then
+	echo "Couldn't determine Qt version; giving up"
+	exit 1
+fi
 
 # Which versions are we building against?
 SQLITE_VERSION=3090200
 LIBXML2_VERSION=2.9.2
 LIBXSLT_VERSION=1.1.28
 LIBZIP_VERSION=0.11.2
-LIBGIT2_VERSION=0.23.4
+LIBGIT2_VERSION=0.26.0
 
 # not on iOS so far, but kept here for completeness
 LIBUSB_VERSION=1.0.19
 LIBFTDI_VERSION=1.2
 
 # set up the Subsurface versions by hand
-GITVERSION=$(git describe --tags --abbrev=12)
-CANONICALVERSION=$(git describe --tags --abbrev=12 | sed -e 's/-g.*$// ; s/^v//' | sed -e 's/-/./')
+GITVERSION=$(git describe --abbrev=12)
+CANONICALVERSION=$(git describe --abbrev=12 | sed -e 's/-g.*$// ; s/^v//' | sed -e 's/-/./')
 MOBILEVERSION=$(grep MOBILE ../../cmake/Modules/version.cmake | cut -d\" -f 2)
 echo "#define GIT_VERSION_STRING \"$GITVERSION\"" > subsurface-mobile/ssrf-version.h
 echo "#define CANONICAL_VERSION_STRING \"$CANONICALVERSION\"" >> subsurface-mobile/ssrf-version.h
@@ -32,6 +37,10 @@ echo "#define MOBILE_VERSION_STRING \"$MOBILEVERSION\"" >> subsurface-mobile/ssr
 # create Info.plist with the correct versions
 cat Info.plist.in | sed "s/@MOBILE_VERSION@/$MOBILEVERSION/;s/@CANONICAL_VERSION@/$CANONICALVERSION/" > Info.plist
 
+if [ "$1" = "version" ] ; then
+	exit 0
+fi
+
 # Build Subsurface-mobile by default
 SUBSURFACE_MOBILE=1
 
@@ -255,24 +264,20 @@ echo next building for $ARCH
 #
 
 # build libdivecomputer
-	if [ ! -d libdivecomputer ] ; then
-		git clone -b Subsurface-branch https://github.com/Subsurface-divelog/libdc.git libdivecomputer
-	fi
-	cd libdivecomputer
-	git pull --rebase
-	if ! git checkout Subsurface-branch ; then
-		echo "can't check out the Subsurface-branch branch of libdivecomputer -- giving up"
-		exit 1
-	fi
-	if [ ! -f configure ] ; then
+	if [ ! -d ../../libdivecomputer/src ] ; then
+		pushd ../..
+		git submodule init
+		git submodule update --recursive
+		pushd libdivecomputer
 		autoreconf --install
+		autoreconf --install
+		popd
+		popd
 	fi
-	cd ..
-
 	if [ ! -e $PKG_CONFIG_LIBDIR/libdivecomputer.pc ] ; then
 		mkdir -p libdivecomputer-build-$ARCH
 		pushd libdivecomputer-build-$ARCH
-		../libdivecomputer/configure --host=${BUILDCHAIN} --prefix=${PREFIX} --enable-static --disable-shared --enable-examples=no --without-libusb --without-hidapi
+		../../../libdivecomputer/configure --host=${BUILDCHAIN} --prefix=${PREFIX} --enable-static --disable-shared --enable-examples=no --without-libusb --without-hidapi --enable-ble
 		make
 		make install
 		popd
@@ -297,3 +302,11 @@ for src in $SRCS; do
 	${IOS_QT}/${QT_VERSION}/ios/bin/lrelease ${SUBSURFACE_SOURCE}/translations/$src -qm translations/${src/.ts/.qm}
 done
 popd
+
+# in order to be able to use xcode without going through Qt Creator
+# call qmake directly
+mkdir -p build-Subsurface-mobile-Qt_$(echo ${QT_VERSION} | tr . _)_for_iOS-Debug
+cd build-Subsurface-mobile-Qt_$(echo ${QT_VERSION} | tr . _)_for_iOS-Debug
+${IOS_QT}/${QT_VERSION}/ios/bin/qmake ../Subsurface-mobile/Subsurface-mobile.pro \
+	-spec macx-ios-clang CONFIG+=iphoneos CONFIG+=device CONFIG+=qml_debug
+make qmake_all
