@@ -1,3 +1,4 @@
+// SPDX-License-Identifier: GPL-2.0
 #ifndef DIVELISTMODEL_H
 #define DIVELISTMODEL_H
 
@@ -13,6 +14,8 @@ class DiveListSortModel : public QSortFilterProxyModel
 	Q_OBJECT
 public:
 	DiveListSortModel(QObject *parent = 0);
+	Q_INVOKABLE void addAllDives();
+	Q_INVOKABLE void clear();
 public slots:
 	int getDiveId(int idx);
 	int getIdxForId(int id);
