@@ -404,9 +404,7 @@ int DivePlannerPointsModel::rowCount(const QModelIndex &parent) const
 
 DivePlannerPointsModel::DivePlannerPointsModel(QObject *parent) : QAbstractTableModel(parent),
 	mode(NOTHING),
-	recalc(false),
-	tempGFHigh(100),
-	tempGFLow(100)
+	recalc(false)
 {
 	memset(&diveplan, 0, sizeof(diveplan));
 	startTime.setTimeSpec(Qt::UTC);
@@ -414,8 +412,8 @@ DivePlannerPointsModel::DivePlannerPointsModel(QObject *parent) : QAbstractTable
 
 DivePlannerPointsModel *DivePlannerPointsModel::instance()
 {
-	static QScopedPointer<DivePlannerPointsModel> self(new DivePlannerPointsModel());
-	return self.data();
+	static DivePlannerPointsModel self;
+	return &self;
 }
 
 void DivePlannerPointsModel::emitDataChanged()
@@ -455,25 +453,18 @@ void DivePlannerPointsModel::setProblemSolvingTime(int minutes)
 
 void DivePlannerPointsModel::setGFHigh(const int gfhigh)
 {
-	tempGFHigh = gfhigh;
-	// GFHigh <= 34 can cause infinite deco at 6m - don't trigger a recalculation
-	// for smaller GFHigh unless the user explicitly leaves the field
-	if (tempGFHigh > 34)
-		triggerGFHigh();
-}
-
-void DivePlannerPointsModel::triggerGFHigh()
-{
-	if (diveplan.gfhigh != tempGFHigh) {
-		diveplan.gfhigh = tempGFHigh;
+	if (diveplan.gfhigh != gfhigh) {
+		diveplan.gfhigh = gfhigh;
 		emitDataChanged();
 	}
 }
 
-void DivePlannerPointsModel::setGFLow(const int ghflow)
+void DivePlannerPointsModel::setGFLow(const int gflow)
 {
-	tempGFLow = ghflow;
-	triggerGFLow();
+	if (diveplan.gflow != gflow) {
+		diveplan.gflow = gflow;
+		emitDataChanged();
+	}
 }
 
 void DivePlannerPointsModel::setRebreatherMode(int mode)
@@ -485,14 +476,6 @@ void DivePlannerPointsModel::setRebreatherMode(int mode)
 	emitDataChanged();
 }
 
-void DivePlannerPointsModel::triggerGFLow()
-{
-	if (diveplan.gflow != tempGFLow) {
-		diveplan.gflow = tempGFLow;
-		emitDataChanged();
-	}
-}
-
 void DivePlannerPointsModel::setVpmbConservatism(int level)
 {
 	if (diveplan.vpmb_conservatism != level) {
@@ -600,14 +583,14 @@ void DivePlannerPointsModel::setDecoMode(int mode)
 	auto planner = SettingsObjectWrapper::instance()->planner_settings;
 	planner->setDecoMode(deco_mode(mode));
 	emit recreationChanged(mode == int(prefs.planner_deco_mode));
-	emit dataChanged(createIndex(0, 0), createIndex(rowCount() - 1, COLUMNS -1));
+	emitDataChanged();
 }
 
 void DivePlannerPointsModel::setSafetyStop(bool value)
 {
 	auto planner = SettingsObjectWrapper::instance()->planner_settings;
 	planner->setSafetyStop(value);
-	emit dataChanged(createIndex(0, 0), createIndex(rowCount() - 1, COLUMNS -1));
+	emitDataChanged();
 }
 
 void DivePlannerPointsModel::setReserveGas(int reserve)
@@ -676,7 +659,7 @@ void DivePlannerPointsModel::setStartTime(const QTime &t)
 
 bool divePointsLessThan(const divedatapoint &p1, const divedatapoint &p2)
 {
-	return p1.time <= p2.time;
+	return p1.time < p2.time;
 }
 
 int DivePlannerPointsModel::lastEnteredPoint()
@@ -1011,6 +994,8 @@ int DivePlannerPointsModel::analyzeVariations(struct decostop *min, struct decos
 #ifdef DEBUG_STOPVAR
 	printf("Total + %d:%02d/%s +- %d s/%s\n\n", FRACTION((leftsum + rightsum) / 2, 60), unit,
 						       (rightsum - leftsum) / 2, unit);
+#else
+	Q_UNUSED(unit)
 #endif
 	return (leftsum + rightsum) / 2;
 }
@@ -1034,7 +1019,7 @@ void DivePlannerPointsModel::computeVariations(struct diveplan *original_plan, s
 	if (in_planner() && prefs.display_variations && decoMode() != RECREATIONAL) {
 		int my_instance = ++instanceCounter;
 		cache_deco_state(&ds, &save);
-		
+
 		duration_t delta_time = { .seconds = 60 };
 		QString time_units = tr("min");
 		depth_t delta_depth;
@@ -1104,6 +1089,9 @@ void DivePlannerPointsModel::computeVariations(struct diveplan *original_plan, s
 finish:
 	free_dps(original_plan);
 	free(original_plan);
+	free(save);
+	free(cache);
+	free(dive);
 //	setRecalc(oldRecalc);
 }
 
