@@ -1,3 +1,4 @@
+// SPDX-License-Identifier: GPL-2.0
 /*
  * An .slg file is composed of a main table (Dives), a bunch of tables directly
  * linked to Dives by their indexes (Site, Suit, Tank, etc) and another group of
@@ -14,14 +15,6 @@
  * to call smartrak_import()
  */
 
-#ifndef __USE_XOPEN
-#define __USE_XOPEN
-#endif
-
-#ifndef _GNU_SOURCE
-#define _GNU_SOURCE
-#endif
-
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -29,6 +22,10 @@
 #include <stdarg.h>
 #include <locale.h>
 
+#if defined(WIN32) || defined(_WIN32)
+#include <windows.h>
+#endif
+
 #include "core/dive.h"
 #include "core/gettext.h"
 #include "core/divelist.h"
@@ -57,7 +54,7 @@ static void smtk_free(char **array, int count)
  * a smarttrak db, and a tiny function which returns the number of the column where
  * a field is expected to be, taking into account the different db formats .
  */
-enum field_pos {IDX = 0, DIVENUM, DATE, INTIME, INTVAL, DURATION, OUTTIME, DESATBEFORE, DESATAFTER, NOFLYBEFORE,
+enum field_pos {IDX = 0, DIVENUM, _DATE, INTIME, INTVAL, DURATION, OUTTIME, DESATBEFORE, DESATAFTER, NOFLYBEFORE,
 		NOFLYAFTER, NOSTOPDECO, MAXDEPTH, VISIBILITY, WEIGHT, O2FRAC, HEFRAC, PSTART, PEND, AIRTEMP,
 		MINWATERTEMP, MAXWATERTEMP, SECFACT, ALARMS, MODE, REMARKS, DCNUMBER, DCMODEL, DIVETIMECOUNT, LOG,
 		PROFILE, SITEIDX, ALTIDX, SUITIDX, WEATHERIDX, SURFACEIDX, UNDERWATERIDX, TANKIDX};
@@ -93,32 +90,47 @@ static int coln(enum field_pos pos)
 /*
  * Fills the date part of a tm structure with the string data obtained
  * from smartrak in format "DD/MM/YY HH:MM:SS" where time is irrelevant.
- * TODO: Verify localization.
  */
 static void smtk_date_to_tm(char *d_buffer, struct tm *tm_date)
 {
-	char *temp = NULL;
+	int n, d, m, y;
 
-	temp = copy_string(d_buffer);
-	strtok(temp, " ");
-	if (temp) {
-		strptime(temp, "%x", tm_date);
-		free(temp);
+	if ((d_buffer) && (!same_string(d_buffer, ""))) {
+		n = sscanf(d_buffer, "%d/%d/%d ", &m, &d, &y);
+		y = (y < 70) ? y + 100 : y;
+		if (n == 3) {
+			tm_date->tm_mday = d;
+			tm_date->tm_mon = m - 1;
+			tm_date->tm_year = y;
+		} else {
+			tm_date->tm_mday = tm_date->tm_mon = tm_date->tm_year = 0;
+		}
+	} else {
+		tm_date->tm_mday = tm_date->tm_mon = tm_date->tm_year = 0;
 	}
 }
 
 /*
  * Fills the time part of a tm structure with the string data obtained
  * from smartrak in format "DD/MM/YY HH:MM:SS" where date is irrelevant.
- * TODO: Verify localization.
  */
 static void smtk_time_to_tm(char *t_buffer, struct tm *tm_date)
 {
-	char *temp = NULL;
+	int n, hr, min, sec;
 
-	temp = index(t_buffer, ' ');
-	if (temp)
-		strptime(temp, "%X", tm_date);
+	if ((t_buffer) && (!same_string(t_buffer, ""))) {
+		n = sscanf(t_buffer, "%*[0-9/] %d:%d:%d ", &hr, &min, &sec);
+		if (n == 3) {
+			tm_date->tm_hour = hr;
+			tm_date->tm_min = min;
+			tm_date->tm_sec = sec;
+		} else {
+			tm_date->tm_hour = tm_date->tm_min = tm_date->tm_sec = 0;
+		}
+	} else {
+		tm_date->tm_hour = tm_date->tm_min = tm_date->tm_sec = 0;
+	}
+	tm_date->tm_isdst = -1;
 }
 
 /*
@@ -129,16 +141,41 @@ static void smtk_time_to_tm(char *t_buffer, struct tm *tm_date)
  */
 static unsigned int smtk_time_to_secs(char *t_buffer)
 {
-	unsigned int n, hr, min, sec;
+	int n, hr, min, sec;
 
 	if (!same_string(t_buffer, "")) {
-		n = sscanf(t_buffer, "%*m[/0-9] %d:%d:%d ", &hr, &min, &sec);
+		n = sscanf(t_buffer, "%*[0-9/] %d:%d:%d ", &hr, &min, &sec);
 		return((n == 3) ? (((hr*60)+min)*60)+sec : 0);
 	} else {
 		return 0;
 	}
 }
 
+/*
+ * Emulate the non portable timegm() function.
+ * Based on timegm man page, changing setenv and unsetenv with putenv,
+ * because of portability issues.
+ */
+static time_t smtk_timegm(struct tm *tm)
+{
+	time_t ret;
+	char *tz, *str;
+
+	tz = getenv("TZ");
+	putenv("TZ=");
+	tzset();
+	ret = mktime(tm);
+	if (tz) {
+		str = calloc(strlen(tz)+4, 1);
+		sprintf(str, "TZ=%s", tz);
+		putenv(str);
+	} else {
+		putenv("TZ");
+	}
+	tzset();
+	return ret;
+}
+
 /*
  * Returns an opened table given its name and mdb. outcol and outbounder have to be allocated
  * by the caller and are filled here.
@@ -279,7 +316,7 @@ static void smtk_wreck_site(MdbHandle *mdb, char *site_idx, struct dive_site *ds
 				case 5:
 					tmp = copy_string(col[i]->bind_ptr);
 					if (tmp)
-						notes = smtk_concat_str(notes, "\n", "%s: %s", wreck_fields[i - 3], rindex(tmp, ' '));
+						notes = smtk_concat_str(notes, "\n", "%s: %s", wreck_fields[i - 3], strrchr(tmp, ' '));
 					free(tmp);
 					break;
 				case 6 ... 9:
@@ -916,9 +953,9 @@ void smartrak_import(const char *file, struct dive_table *divetable)
 		smtk_clean_cylinders(smtkdive);
 
 		/* Date issues with libdc parser - Take date time from mdb */
-		smtk_date_to_tm(col[coln(DATE)]->bind_ptr, tm_date);
+		smtk_date_to_tm(col[coln(_DATE)]->bind_ptr, tm_date);
 		smtk_time_to_tm(col[coln(INTIME)]->bind_ptr, tm_date);
-		smtkdive->dc.when = smtkdive->when = timegm(tm_date);
+		smtkdive->dc.when = smtkdive->when = smtk_timegm(tm_date);
 		free(tm_date);
 		smtkdive->dc.surfacetime.seconds = smtk_time_to_secs(col[coln(INTVAL)]->bind_ptr);
 
