@@ -1,3 +1,4 @@
+// SPDX-License-Identifier: GPL-2.0
 #include <stdlib.h>
 #include <stdio.h>
 #include "core/dive.h"
@@ -16,13 +17,19 @@ int main(int argc, char *argv[])
 {
 	char *infile, *outfile;
 	int i;
+#ifndef COMMANDLINE
 	QApplication a(argc, argv);
 	Smrtk2ssrfcWindow w;
+#else
+	QCoreApplication a(argc, argv);
+#endif
 
 	switch (argc) {
 	case 1:
+#ifndef COMMANDLINE
 		w.show();
 		return a.exec();
+#endif
 		break;
 	case 2:
 		qDebug() << "\nUsage:\n";
